dhcpkit.ipv6.server.extensions.static_assignments.csv module
============================================================

.. automodule:: dhcpkit.ipv6.server.extensions.static_assignments.csv
    :members:
    :undoc-members:
    :show-inheritance:
